@@ -32,7 +32,7 @@ from tiddlywebplugins.prettyerror import PrettyHTTPExceptor
 import tiddlywebplugins.status
 
 
-__version__ = '0.9.82'
+__version__ = '0.9.83'
 
 
 def init(config):
@@ -57,7 +57,6 @@ def init(config):
     import tiddlywebplugins.privateer
     import tiddlywebplugins.relativetime
     import tiddlywebplugins.jsonp
-    import tiddlywebplugins.kml
 
     @make_command()
     def addmember(args):
@@ -115,7 +114,6 @@ def init(config):
     tiddlywebplugins.lazy.init(config)
     tiddlywebplugins.privateer.init(config)
     tiddlywebplugins.jsonp.init(config)
-    tiddlywebplugins.kml.init(config)
 
     # XXX: The following is required to work around issues with twp.instancer.
     # Without this, config settings from tiddlywebwiki take precedence.
